//+------------------------------------------------------------------+
//|                                                      renkoEA.mq4 |
//|                        Copyright 2020, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict

#include <mq4.mqh>

#property show_inputs




input int points = 250;
input double ratio = 1.8;
input double renko_slip = 0.0025;
input double buffer = 0.0007;
input double risk = 0.04;
input double tpsl_magnitude = 1.25;
int magicnum = 123;
int orderID;
int renko_handle;

   double rh[1];
   double rl[1];
   double entry_signal[1];
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
   renko_handle = iCustom(Symbol(), Period(), "Examples\\renko", points, ratio, renko_slip);
  
   Alert("EA has started");

return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
  IndicatorRelease(renko_handle);
  
   Alert("EA CLOSED");

  
  

   
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
{
   if(!Newbar()) return;

   
   int cnt = CopyBuffer(renko_handle, 4,1,1,entry_signal);
   if (cnt<1) return;
     cnt= CopyBuffer(renko_handle, 1,1,1,rh);
     cnt=CopyBuffer(renko_handle, 2,1,1,rl); 
  
  
   
  

   
   double get_pip = 1/Point;
   
 //=======================================risk management =======================================  
   Print("E1"+ DoubleToStr(entry_signal[0]));

   Print("high"+rh[0]);
   Print("low"+rl[0]);
   Print(renko_handle);
   
 //==============================================================================================
  
 

    
 
   
  if(!CheckIfOpenOrdersByMagicNB(magicnum))
   {
      if ( entry_signal[0] == 1.0 )
         {  
            double entry_price = Open[0];
            double buy_sl_points = MathAbs(entry_price-rl[0])+buffer;
            double buy_sl_level = NormalizeDouble(rl[0] - buffer , Digits);
            double buy_sl_pips= (buy_sl_points * get_pip / 10);
            
            double buy_tp_points = MathFloor(buy_sl_points * tpsl_magnitude * get_pip / 10) * 10 * Point;
            double buy_tp_level = NormalizeDouble( entry_price + buy_tp_points, Digits);
  
            double accEquity= AccountEquity() ;
   
            double accType= MarketInfo(Symbol(),MODE_LOTSIZE);
            
            double max_loss_base = risk * accEquity;
            
            double tickvalue = MarketInfo(Symbol(),MODE_TICK_VALUE);
            if (Digits <= 3)
            {
               tickvalue = tickvalue/100;
            }
            
            double max_loss_quote = max_loss_base/ tickvalue;
            
            double size = NormalizeDouble((max_loss_quote / buy_sl_points)/accType , 2);
            
            Print("buy_sl"+buy_sl_level);
            Print("buy_tp" + buy_tp_level);
            Print("size"+size);
            Print("rl" + "..."+ rl[0]); 
            Print ("ENTRY  "+ entry_price);
            Print( accType);
            Print(buy_sl_points);
            Print("maxlossquote" +max_loss_quote);
            Print("loss base" + max_loss_base);
            Print("equity"+ accEquity);
            Print(accType);
            Print(MODE_MINLOT);
            
            orderID=OrderSend(NULL,OP_BUY, size ,Ask ,50,buy_sl_level,buy_tp_level,NULL, magicnum);
            Alert(orderID);
        
            if(orderID<0)
            {Alert("trade rejected, check margin, sl, tp"+ GetLastError());}    
         
            else 
            {
               Alert("order successful");
            }
          }
          
          
       else if(entry_signal[0] == 2.0 )//sell order 
       {
         double entry_price= Open[0];
         double sell_sl_points = MathAbs(rh[0] - entry_price)+buffer;
         double sell_sl_level = NormalizeDouble(rh[0] +buffer,Digits);
         double sell_sl_pips = (sell_sl_points * get_pip/10);
         
         double sell_tp_lvl = entry_price - (sell_sl_points*tpsl_magnitude);
         double sell_tp_points = (MathFloor((entry_price- sell_tp_lvl)* get_pip/10))*10*Point;
         double sell_tp_level = entry_price-(sell_tp_points);
         
         
        double accEquity= AccountEquity();
   
            double accType= MarketInfo(Symbol(),MODE_LOTSIZE);

            double max_loss_base = risk * accEquity;
            
            double tickvalue = MarketInfo(Symbol(),MODE_TICK_VALUE);
            if (Digits <= 3)
            {
               tickvalue = tickvalue/100;
            }
            
            
            double max_loss_quote = max_loss_base/ tickvalue;
            
            double size = NormalizeDouble((max_loss_quote / sell_sl_points )/accType,2);
         
         
         Print("sell_sl"+sell_sl_level);
            Print("SELL_tp" + sell_tp_level);
            Print("size"+size);
            Print("rh" + "..."+ rh[0]); 
            Print ("bid  "+ Bid);
           
         
         
         
         
         orderID=OrderSend(NULL, OP_SELL, size,Bid,50, sell_sl_level, sell_tp_level,NULL, magicnum );
         Alert(orderID);
         
         if(orderID<0)
         {Alert("trade rejected, check margin, sl, tp, error is" + GetLastError());}// order rejected maybe stoploss and take profit too tight}
        
         else
         { 
           Alert(" trade successful");
         }
       }
        
    }    
   
}

  

//+------------------------------------------------------------------+
bool CheckIfOpenOrdersByMagicNB(int magicnum)
   {
   int openOrders = OrdersTotal();
   for(int i = 0; i < openOrders; i++)
   {
     if(OrderSelect(i,SELECT_BY_POS)==true)
      {
         if(OrderMagicNumber() == magicnum) 
         {
            return true;
         }  
      }
   }
   return false;
 

   
}



bool Newbar()
{
   static datetime prevTime= 0;
   datetime        currentTime = iTime(Symbol(),Period(),0);
   if (currentTime!=prevTime)
   {
      prevTime = currentTime;
      return(true);
   }
   
   return(false);
}